ElmoreDelayCalculator

Struct ElmoreDelayCalculator 

pub struct ElmoreDelayCalculator {
    pub unit_resistance: f64,
    pub unit_capacitance: f64,
}
Elmore delay model: considers distributed wire resistance and capacitance.

delay = R * (C / 2 + load_capacitance) where R and C are the total resistance and capacitance of the wire segment.

Fields

unit_resistance: f64

Resistance per unit length of wire

unit_capacitance: f64

Capacitance per unit length of wire

Implementations

Source

impl ElmoreDelayCalculator

pub fn new(unit_resistance: f64, unit_capacitance: f64) -> Self

Creates an Elmore delay calculator with the given resistance and capacitance per unit length.