LinearDelayCalculator

Struct LinearDelayCalculator 

pub struct LinearDelayCalculator {
    pub delay_per_unit: f64,
    pub capacitance_per_unit: f64,
}
Linear delay model where wire delay is proportional to wire length.

delay = delay_per_unit * length

Fields

delay_per_unit: f64

Delay per unit length of wire

capacitance_per_unit: f64

Capacitance per unit length of wire

Implementations

Source

impl LinearDelayCalculator

pub fn new(delay_per_unit: f64, capacitance_per_unit: f64) -> Self

Creates a linear delay calculator with the given parameters.