pub struct Tree {
pub root: Option<NodeIdx>,
/* private fields */
}Expand description
Arena-allocated tree of TreeNodes.
Nodes are stored in a Vec and referenced by their index.
This avoids Rc<RefCell<>> while still allowing safe mutation
during bottom-up merging and top-down embedding phases.
Fields
root: Option<NodeIdx>Index of the root node, if the tree has been built.
Implementations
Sourceimpl Tree
impl Tree
Sourcepub fn get(&self, idx: NodeIdx) -> &TreeNode
pub fn get(&self, idx: NodeIdx) -> &TreeNode
Returns a shared reference to the node at the given index.
Sourcepub fn get_mut(&mut self, idx: NodeIdx) -> &mut TreeNode
pub fn get_mut(&mut self, idx: NodeIdx) -> &mut TreeNode
Returns a mutable reference to the node at the given index.