Module error

Module error 

Error types for geometric operations Error types for physdes-rs

This module provides comprehensive error handling for geometric operations.

Enums

GeomError
Error type for geometric operations

Type Aliases

GeomResult
Result type for geometric operations