Module interval
physdes
0.1.6
Module interval
Module Items
Structs
Traits
In crate physdes
physdes
Module
interval
Interval operations and types
Structs

Interval
A range of values with a lower bound (
lb
) and an upper bound (
ub
).
Traits

Enlarge
Trait for enlarging a value by a given margin.
Hull
Trait for computing the convex hull (bounding interval) of two values.
Intersect
Trait for computing the intersection of two values.