Interval

Struct Interval 

pub struct Interval<T> {
    pub lb: T,
    pub ub: T,
    pub _marker: PhantomData<T>,
}
A range of values with a lower bound (lb) and an upper bound (ub).

 lb        ub
  |---------|
  *=========*-----> T

An interval is valid when lb <= ub. The is_invalid() method checks for the invalid case lb > ub.

Examples

use physdes::interval::Interval;

let interval = Interval::new(1, 5);
assert_eq!(interval.lb, 1);
assert_eq!(interval.ub, 5);

Fields

lb: Tub: T_marker: PhantomData<T>

Implementations

Source

impl<T> Interval<T>

pub const fn new(lb: T, ub: T) -> Self

Creates a new interval with the given lower and upper bounds.

Note: No validity check is performed. An interval where lb > ub is considered invalid and can be checked with is_invalid().

Examples
use physdes::interval::Interval;

let interval = Interval::new(1, 5);
assert_eq!(interval.lb, 1);
assert_eq!(interval.ub, 5);

let interval = Interval::new(5, 1);  // Invalid interval but still created
assert_eq!(interval.lb, 5);
assert_eq!(interval.ub, 1);
Source

impl<T: Copy> Interval<T>

pub const fn lb(&self) -> T

Returns the lower bound.

pub const fn ub(&self) -> T

Returns the upper bound.

Source

impl<T: PartialOrd> Interval<T>

pub fn is_invalid(&self) -> bool

Returns true if the lower bound exceeds the upper bound (invalid interval).

Examples
use physdes::interval::Interval;

let valid_interval = Interval::new(1, 5);
assert!(!valid_interval.is_invalid());

let invalid_interval = Interval::new(5, 1);
assert!(invalid_interval.is_invalid());
Source

impl<T: Copy + Sub<Output = T>> Interval<T>

pub fn length(&self) -> T

Computes the length of the interval: ub - lb.

$$L = ub - lb$$

Examples
use physdes::interval::Interval;

let interval = Interval::new(2, 8);
assert_eq!(interval.length(), 6);

let interval = Interval::new(-3, 5);
assert_eq!(interval.length(), 8);