pub trait Hull<T: ?Sized> {
type Output;
// Required method
fn hull_with(&self, other: &T) -> Self::Output;
}Expand description
The above code is defining a trait named Hull in Rust. This trait has a generic type T that must
be sized. It also has an associated type Output. The trait has a method hull_with that takes a
reference to another object of type T and returns an object of type Output. This trait can be
implemented for different types to provide the hull_with functionality.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Hull<i32> for i32
impl Hull<i32> for i32
Sourcefn hull_with(&self, other: &i32) -> Self::Output
fn hull_with(&self, other: &i32) -> Self::Output
The function hull_with calculates the lower and upper bounds between two values.
Arguments:
other: Theotherparameter in thehull_withfunction is a reference to ani32type. This parameter is used to calculate the lower bound (lb) and upper bound (ub) values for the output struct.