pub struct Interval<T> {
pub lb: T,
pub ub: T,
pub _marker: PhantomData<T>,
}Expand description
A range of values with a lower bound (lb) and an upper bound (ub).
lb ub
|---------|
*=========*-----> TAn interval is valid when lb <= ub. The is_invalid() method checks for the
invalid case lb > ub.
Examples
use physdes::interval::Interval;
let interval = Interval::new(1, 5);
assert_eq!(interval.lb, 1);
assert_eq!(interval.ub, 5);Fields
lb: Tub: T_marker: PhantomData<T>Implementations
Sourceimpl<T> Interval<T>
impl<T> Interval<T>
Sourcepub const fn new(lb: T, ub: T) -> Self
pub const fn new(lb: T, ub: T) -> Self
Creates a new interval with the given lower and upper bounds.
Note: No validity check is performed. An interval where lb > ub is considered
invalid and can be checked with is_invalid().
Examples
use physdes::interval::Interval;
let interval = Interval::new(1, 5);
assert_eq!(interval.lb, 1);
assert_eq!(interval.ub, 5);
let interval = Interval::new(5, 1); // Invalid interval but still created
assert_eq!(interval.lb, 5);
assert_eq!(interval.ub, 1);Sourceimpl<T: PartialOrd> Interval<T>
impl<T: PartialOrd> Interval<T>
Sourcepub fn is_invalid(&self) -> bool
pub fn is_invalid(&self) -> bool
Returns true if the lower bound exceeds the upper bound (invalid interval).
Examples
use physdes::interval::Interval;
let valid_interval = Interval::new(1, 5);
assert!(!valid_interval.is_invalid());
let invalid_interval = Interval::new(5, 1);
assert!(invalid_interval.is_invalid());Trait Implementations
Sourceimpl<T: Add<Output = T>> Add for Interval<T>
Interval addition (component-wise): $[a,b] + [c,d] = [a+c,; b+d]$
impl<T: Add<Output = T>> Add for Interval<T>
Interval addition (component-wise): $[a,b] + [c,d] = [a+c,; b+d]$
Sourceimpl<T> AddAssign<T> for Interval<T>
impl<T> AddAssign<T> for Interval<T>
Sourcefn add_assign(&mut self, rhs: T)
fn add_assign(&mut self, rhs: T)
Shift the interval by a scalar: $[a,b] \mathrel{+}= t \implies [a+t,; b+t]$
Sourceimpl<T: PartialOrd> Contain<T> for Interval<T>
impl<T: PartialOrd> Contain<T> for Interval<T>
impl<T: Copy> Copy for Interval<T>
Sourceimpl<T> Displacement<Interval<T>> for Interval<T>where
T: Displacement<T, Output = T>,
impl<T> Displacement<Interval<T>> for Interval<T>where
T: Displacement<T, Output = T>,
impl<T: Eq> Eq for Interval<T>
Sourceimpl<T> Hull<T> for Interval<T>
impl<T> Hull<T> for Interval<T>
Sourcefn hull_with(&self, other: &T) -> Self::Output
fn hull_with(&self, other: &T) -> Self::Output
The hull_with function calculates the hull (minimum and maximum values) between two values.
Arguments:
other: Theotherparameter is a reference to a value of typeT, which is the same type as the values stored in the struct implementing thehull_withmethod. In this method, theothervalue is used to update the lower bound (lb) and upper bound (`
type Output = Interval<T>
Sourceimpl MinDist<i32> for Interval<i32>
impl MinDist<i32> for Interval<i32>
Sourcefn min_dist_with(&self, other: &i32) -> u32
fn min_dist_with(&self, other: &i32) -> u32
Computes the minimum distance between an interval and a scalar value.
Sourceimpl<T> MulAssign<T> for Interval<T>
impl<T> MulAssign<T> for Interval<T>
Sourcefn mul_assign(&mut self, rhs: T)
fn mul_assign(&mut self, rhs: T)
Scale the interval by a scalar: $[a,b] \mathrel{*}= t \implies [a \cdot t,; b \cdot t]$
Sourceimpl<T: PartialOrd> Overlap<T> for Interval<T>
impl<T: PartialOrd> Overlap<T> for Interval<T>
Sourceimpl<T: PartialEq> PartialEq for Interval<T>
impl<T: PartialEq> PartialEq for Interval<T>
Sourceimpl<T: PartialOrd> PartialOrd for Interval<T>
impl<T: PartialOrd> PartialOrd for Interval<T>
Sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
Orders intervals by their position: Less if ub < other.lb, Greater if other.ub < self.lb, Equal otherwise.
Examples
use physdes::interval::Interval;
use std::marker::PhantomData;
assert_eq!(Interval::new(1, 2).partial_cmp(&Interval::new(3, 4)), Some(std::cmp::Ordering::Less));impl<T: PartialEq> StructuralPartialEq for Interval<T>
Sourceimpl<T: Sub<Output = T>> Sub for Interval<T>
Interval subtraction (component-wise): $[a,b] - [c,d] = [a-c,; b-d]$
impl<T: Sub<Output = T>> Sub for Interval<T>
Interval subtraction (component-wise): $[a,b] - [c,d] = [a-c,; b-d]$