MergeObj

Struct MergeObj 

pub struct MergeObj<T1, T2> { /* private fields */ }
Represents a merge object that encapsulates a point with coordinates of type T1 and T2.

The MergeObj struct is used for geometric operations such as distance calculation, enlargement, intersection, and merging with other merge objects.

Examples

use physdes::merge_obj::MergeObj;

let merge_obj = MergeObj::new(3, 4);
let internal_point = merge_obj.get_impl();
assert_eq!(internal_point.xcoord, 3);
assert_eq!(internal_point.ycoord, 4);

Implementations

Source

impl<T1, T2> MergeObj<T1, T2>

pub const fn new(xcoord: T1, ycoord: T2) -> MergeObj<T1, T2>

pub const fn construct(xcoord: i32, ycoord: i32) -> MergeObj<i32, i32>

pub fn get_impl(&self) -> &Point<T1, T2>

Returns a reference to the internal Point of the MergeObj

Examples
use physdes::merge_obj::MergeObj;

let merge_obj = MergeObj::new(3, 4);
let internal_point = merge_obj.get_impl();
assert_eq!(internal_point.xcoord, 3);
assert_eq!(internal_point.ycoord, 4);
Source

impl<T1, T2> MergeObj<T1, T2>
where T1: MinDist<T1>, T2: MinDist<T2>,

pub fn min_dist_with(&self, other: &MergeObj<T1, T2>) -> u32

Source

impl<T1, T2> MergeObj<T1, T2>
where T1: MinDist<T1> + Enlarge<i32, Output = T1> + Intersect<T1, Output = T1>, T2: MinDist<T2> + Enlarge<i32, Output = T2> + Intersect<T2, Output = T2>,

pub fn enlarge_with(&self, alpha: i32) -> MergeObj<T1, T2>

pub fn intersect_with(&self, other: &MergeObj<T1, T2>) -> MergeObj<T1, T2>

pub fn merge_with(&self, other: &MergeObj<T1, T2>) -> MergeObj<T1, T2>